==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebDockingIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockingIndicatorDescription } from "./WebDockingIndicatorDescription";
/**
 * @hidden
 */
var WebDockingIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebDockingIndicatorDescriptionMetadata, _super);
    function WebDockingIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDockingIndicatorDescriptionMetadata.b = function (a) {
        if (WebDockingIndicatorDescriptionMetadata.a == null) {
            WebDockingIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDockingIndicatorDescriptionMetadata.c(WebDockingIndicatorDescriptionMetadata.a);
        }
        if (a.k(WebDockingIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebDockingIndicatorDescriptionMetadata.a);
    };
    WebDockingIndicatorDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:DockingIndicator");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__skipSuffix", "Boolean");
        a.item("Position", "ExportedType:string:DockingIndicatorPosition");
        a.item("Position@stringUnion", "WebComponents;React");
        a.item("Position@names", "Left;OuterLeft;Right;OuterRight;Top;OuterTop;Bottom;OuterBottom;Center");
        a.item("IsRoot", "Boolean");
    };
    WebDockingIndicatorDescriptionMetadata.d = function (a) {
        WebDockingIndicatorDescriptionMetadata.b(a);
        a.ad("WebDockingIndicator", function () { return new WebDockingIndicatorDescription(); });
        a.ac("WebDockingIndicator", WebDockingIndicatorDescriptionMetadata.a);
    };
    WebDockingIndicatorDescriptionMetadata.$t = markType(WebDockingIndicatorDescriptionMetadata, 'WebDockingIndicatorDescriptionMetadata');
    WebDockingIndicatorDescriptionMetadata.a = null;
    return WebDockingIndicatorDescriptionMetadata;
}(Base));
export { WebDockingIndicatorDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/WebDockingIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockingIndicatorDescription } from "./WebDockingIndicatorDescription";
/**
 * @hidden
 */
var WebDockingIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebDockingIndicatorDescriptionMetadata, _super);
    function WebDockingIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDockingIndicatorDescriptionMetadata.b = function (a) {
        if (WebDockingIndicatorDescriptionMetadata.a == null) {
            WebDockingIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDockingIndicatorDescriptionMetadata.c(WebDockingIndicatorDescriptionMetadata.a);
        }
        if (a.k(WebDockingIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebDockingIndicatorDescriptionMetadata.a);
    };
    WebDockingIndicatorDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:DockingIndicator");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__skipSuffix", "Boolean");
        a.item("Position", "ExportedType:string:DockingIndicatorPosition");
        a.item("Position@stringUnion", "WebComponents;React");
        a.item("Position@names", "Left;OuterLeft;Right;OuterRight;Top;OuterTop;Bottom;OuterBottom;Center");
        a.item("IsRoot", "Boolean");
        a.item("Direction", "String");
    };
    WebDockingIndicatorDescriptionMetadata.d = function (a) {
        WebDockingIndicatorDescriptionMetadata.b(a);
        a.ae("WebDockingIndicator", function () { return new WebDockingIndicatorDescription(); });
        a.ad("WebDockingIndicator", WebDockingIndicatorDescriptionMetadata.a);
    };
    WebDockingIndicatorDescriptionMetadata.$t = markType(WebDockingIndicatorDescriptionMetadata, 'WebDockingIndicatorDescriptionMetadata');
    WebDockingIndicatorDescriptionMetadata.a = null;
    return WebDockingIndicatorDescriptionMetadata;
}(Base));
export { WebDockingIndicatorDescriptionMetadata };
